@@ -201,27 +201,8 @@ case_ <- names(data)
 
 nardl_fit_case_ <- lm(nardl_fmla, data = nardl_data, na.action = na.exclude)
 
-{
-  if("(Intercept)" %in% names(nardl_fit_case_$coefficients) == TRUE){
-    keep_val <- c(1)
-  }
-  else{
-    keep_val <- NULL
-  }
-}
-
-{
-  if("trend" %in% names(nardl_fit_case_$coefficients) == TRUE){
-    keep_val <- c(keep_val,length(nardl_fit_case_$coefficients))
-  }
-  else{
-    keep_val <- keep_val
-  }
-}
-
 nardl_gets_fit <- gets.lm(nardl_fit_case_,
                           wald.pval=gets_pval,
-                          keep = keep_val,
                           include.1cut = T,print.searchinfo = F)
 
 
@@ -361,35 +342,35 @@ ecm_gets_summ <- summary(ecm_gets_fit)
 ecm_diag_gets <- round(diag <- diagnostics(ecm_gets_summ,
                                             ar.LjungB=c(floor(max(q_order)/2), 0.025),
                                             arch.LjungB = NULL, 
-                                            normality.JarqueB = NULL),3)
+                                            normality.JarqueB = NULL),4)
 
 jbtest <- c()
-jbtest$statistic <- round(jarque.bera.test(ecm_gets_fit$residuals)$statistic,2)
-jbtest$p.value <- round(jarque.bera.test(ecm_gets_fit$residuals)$p.value,2)
+jbtest$statistic <- round(jarque.bera.test(ecm_gets_fit$residuals)$statistic,4)
+jbtest$p.value <- round(jarque.bera.test(ecm_gets_fit$residuals)$p.value,4)
 jbtest <- cbind(jbtest)
 jbtest <- cbind(jbtest[[1]],jbtest[[2]])
 colnames(jbtest) <- c('statistics','p.value')
 rownames(jbtest) <- dep_var
 
 lm_test <- c()
-lm_test$statistic <- round(bgtest(ecm_gets_fit, type = "Chisq", order = order_l)$statistic,2)
-lm_test$p.value <- round(bgtest(ecm_gets_fit, type = "Chisq", order = order_l)$p.value,2)
+lm_test$statistic <- round(bgtest(ecm_gets_fit, type = "Chisq", order = order_l)$statistic,4)
+lm_test$p.value <- round(bgtest(ecm_gets_fit, type = "Chisq", order = order_l)$p.value,4)
 lm_test <- cbind(lm_test)
 lm_test <- cbind(lm_test[[1]],lm_test[[2]])
 colnames(lm_test) <- c('statistics','p.value')
 rownames(lm_test) <- dep_var
 
 arch <- c()
-arch$statistic <- round(ArchTest(ecm_gets_fit$residuals, order_l)$statistic,2)
-arch$p.value <- round(ArchTest(ecm_gets_fit$residuals, order_l)$p.value,2)
+arch$statistic <- round(ArchTest(ecm_gets_fit$residuals, order_l)$statistic,4)
+arch$p.value <- round(ArchTest(ecm_gets_fit$residuals, order_l)$p.value,4)
 arch <- cbind(arch)
 arch <- cbind(arch[[1]],arch[[2]])
 colnames(arch) <- c('statistics','p.value')
 rownames(arch) <- dep_var
 
 reset_test <- c()
-reset_test$statistic <- round(resettest(ecm_gets_fit, power = 2, type = 'princomp')$statistic,2)
-reset_test$p.value <- round(resettest(ecm_gets_fit, power = 2, type = 'princomp')$p.value,2)
+reset_test$statistic <- round(resettest(ecm_gets_fit, power = 2, type = 'princomp')$statistic,4)
+reset_test$p.value <- round(resettest(ecm_gets_fit, power = 2, type = 'princomp')$p.value,4)
 reset_test <- cbind(reset_test)
 reset_test <- cbind(reset_test[[1]],reset_test[[2]])
 colnames(reset_test) <- c('statistics','p.value')
@@ -401,8 +382,7 @@ rownames(diag) <- c('BG_SC_lm_test', 'LM_ARCH_test','normality_test', 'RESET_tes
 coof_lres <- coof[c(bn, bp)]
 vcc1 <- vcc[c(names(coof_lres[1]), names(coof_lres[2])), 
             c(names(coof_lres[1]), names(coof_lres[2]))]
-lbeta <- coeff[c(names(coof_lres[1]), names(coof_lres[2])), 
-               1]
+lbeta <- coeff[c(names(coof_lres[1]), names(coof_lres[2])), 1]
 
 ll2 <- c(paste(names(coof_lres[1]), "=", names(coof_lres[2])))
 
@@ -412,54 +392,54 @@ rownames(lr_asym_test) <- decomp
 
 decomp_d = paste0("D.", decomp)
 sr_cof_nm <- str_subset(rownames(coeff), decomp_d)
-don <- dim(as.data.frame(str_subset(sr_cof_nm, pattern = '_neg')))[1]
-dop <- dim(as.data.frame(str_subset(sr_cof_nm, pattern = '_pos')))[1]
 coeff_sr <- coeff[sr_cof_nm, ]
-d_pos <- sr_cof_nm[1:(length(sr_cof_nm)/2)]
-d_neg <- sr_cof_nm[(length(d_pos) + 1):length(sr_cof_nm)]
 
+don <- dim(as.data.frame(str_subset(sr_cof_nm, pattern = "_neg")))[1]
+dop <- dim(as.data.frame(str_subset(sr_cof_nm, pattern = "_pos")))[1]
+nnn <- str_subset(sr_cof_nm, pattern = "_neg")
+ppp <- str_subset(sr_cof_nm, pattern = "_pos")
+
+neg <- str_flatten(paste(str_subset(sr_cof_nm, pattern = "_neg"), ' '))
+pos <- str_flatten(paste(str_subset(sr_cof_nm, pattern = "_pos"), ' '))
 {
-  if(don > 0 & dop > 0 ){
-    dddneg <- paste(d_neg, "+")
-    dddpos <- paste(d_pos, "+")
-    plus_ <- dddpos[[length(dddpos)]]
-    plus_ <- gsub(x = plus_, pattern = "[+]| ", replacement = "")
-    plus_ <- paste(plus_, "=")
-    dddpos <- str_flatten(c(dddpos[-length(dddpos)], plus_))
-    neg_ <- dddneg[[length(dddneg)]]
-    neg_ <- gsub(x = neg_, pattern = "[+]| ", replacement = "")
-    dddneg <- str_flatten(c(dddneg[-length(dddneg)], neg_))
-    pos_neg <- str_c(dddpos, dddneg)
-    wld_test <- linearHypothesis(ecm_gets_fit, hypothesis.matrix = pos_neg, verbose = F,test = "F")
+  if (don > 0 & dop > 0) {
+    neg = paste(str_split(neg, boundary("word"))[[1]],'+')
+    pos = paste(str_split(pos, boundary("word"))[[1]],'+')
+    pos = c('=', pos)
+    pos = c(pos[-length(pos)],str_split(pos[length(pos)], boundary("word"))[[1]])
+    neg = c(neg[-length(neg)], str_split(neg[length(neg)], boundary("word"))[[1]])
+    pos_neg <- str_flatten(c(neg, pos))
+    wld_test <- linearHypothesis(ecm_gets_fit, hypothesis.matrix = pos_neg, verbose = F, test = "F")
     sr_asym_test <- cbind(Fstat = wld_test$F[2], Pval = wld_test$`Pr(>F)`[2])
     rownames(sr_asym_test) <- decomp
     sr_asym_test
   }
-  else{
-    if(length(d_pos) > 1){
-      dddneg <- paste(d_neg, " + ")
-      dddpos <- paste(d_pos," = 0")
-      plus_ <- dddpos[[length(dddpos)]]
-      plus_ <- gsub(x = plus_, pattern = "[=0]| ", replacement = "")
-      plus_ <- paste(plus_,' + ')
-      dddpos <- str_flatten(c(plus_, dddpos[-length(dddpos)]))
-      pos_neg <-  str_flatten(c(dddneg,dddpos))
-      wld_test <- linearHypothesis(ecm_gets_fit, hypothesis.matrix = pos_neg, verbose = F,test = "F")
-      sr_asym_test <- cbind(Fstat = wld_test$F[2], Pval = wld_test$`Pr(>F)`[2])
+  else {
+    if (length(ppp) > 0) {
+      pos = paste(str_split(pos, boundary("word"))[[1]],'+')
+      pos = c(pos[-length(pos)],str_split(pos[length(pos)], boundary("word"))[[1]])
+      pos = c(pos,'= 0')
+      pos_h <- str_flatten(pos)
+      wld_test <- linearHypothesis(ecm_gets_fit, hypothesis.matrix = pos_h, verbose = F, test = "F")
+      sr_asym_test <- cbind(Fstat = wld_test$F[2],  Pval = wld_test$`Pr(>F)`[2])
       rownames(sr_asym_test) <- decomp
       sr_asym_test
     }
-    else{
-      dddneg <- paste(d_neg, " + ")
-      dddpos <- paste(d_pos," = 0")
-      pos_neg <-  str_flatten(c(dddneg,dddpos))
-      wld_test <- linearHypothesis(ecm_gets_fit, hypothesis.matrix = pos_neg, verbose = F,test = "F")
-      sr_asym_test <- cbind(Fstat = wld_test$F[2], Pval = wld_test$`Pr(>F)`[2])
+    else {
+      neg = paste(str_split(neg, boundary("word"))[[1]],'+')
+      neg = c(neg[-length(neg)],str_split(neg[length(neg)], boundary("word"))[[1]])
+      neg = c(neg,'= 0')
+      neg_h <- str_flatten(neg)
+      wld_test <- linearHypothesis(ecm_gets_fit, hypothesis.matrix = neg_h, 
+                                   verbose = F, test = "F")
+      sr_asym_test <- cbind(Fstat = wld_test$F[2], 
+                            Pval = wld_test$`Pr(>F)`[2])
       rownames(sr_asym_test) <- decomp
       sr_asym_test
     }
   }
 }
+
 nobs <- nobs(ecm_gets_fit)
 e <- ecm_gets_fit$residuals
 stab_plot <- function(graph_save) {
