@@ -1,5 +1,5 @@
-# Rename the coefficients   --------------------
-output_ren <- function(x,listn=listn,D.patern,D.repl,l.patern,l.repl){
+output_ren <- function(x,listn=listn,D.patern,D.repl,l.patern,l.repl)
+  {
   lr_names <-lapply(1:length(listn), function(i) rownames(x[[i]]$Longrun_relation))
   lr_newnames_sr <- c()
   lr_newnames_sr <- lapply(1:length(lr_names), function(i)
@@ -11,8 +11,6 @@ output_ren <- function(x,listn=listn,D.patern,D.repl,l.patern,l.repl){
   for (i in 1:length(lr_names)) {
     rownames(x[[i]]$Longrun_relation) <- c(lr_newnames_sr[[i]])
   }
-  
-  #############################################################
   uecm_names <-lapply(1:length(listn), function(i) 
     rownames(x[[i]]$UECM$coefficients))
   
@@ -20,14 +18,9 @@ output_ren <- function(x,listn=listn,D.patern,D.repl,l.patern,l.repl){
     gsub(x = uecm_names,  pattern = D.patern,  replacement = D.repl))
   uecm_new_names <- lapply(1:length(uecm_names), function(i)
     gsub(x = uecm_names[[i]],  pattern = l.patern,  replacement = l.repl))
-  uecm_new_names
   names(uecm_new_names) <- listn
-  uecm_new_names
-  
   for (i in 1:length(uecm_names)) {
     rownames(x[[i]]$UECM$coefficients) <- c(uecm_new_names[[i]])
   }
   return(x)
-}
-
-
+}
\ No newline at end of file
